#<profile4xi profile = "12" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "constant_connection4xi.py">
#<abstract4xi abstract = "Provides the class ConstantConnection4Xi."/>
#<refer4xi reference = "connection.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'constant_connection4xi', 'ConstantConnection4Xi',
            'init_message_length4xi', 'set_message_length4xi', 'get_message_length4xi', 
            'init_challenge4xi', 'set_challenge4xi', 'get_challenge4xi',
            'init_welcome4xi', 'set_welcome4xi', 'get_welcome4xi',
            'init_failure4xi', 'set_failure4xi', 'get_failure4xi',
            'init_max_response_message_length4xi', 'set_max_response_message_length4xi', 'get_max_response_message_length4xi',
            'init_localhost4xi', 'set_localhost4xi', 'get_localhost4xi',
            'init_buffersize4xi', 'set_buffersize4xi', 'get_buffersize4xi',
            'init_connectiontimeout4xi', 'set_connectiontimeout4xi', 'get_connectiontimeout4xi'] #[Rel 7.21] 
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
import errno
import io
import itertools
import os
import pickle
import select
import socket
import struct
import sys
import time
import tempfile
try:
    import _winapi
    from _winapi import WAIT_OBJECT_0, WAIT_TIMEOUT, INFINITE
except ImportError:
    if sys.platform == 'win32':
        raise
    _winapi = None 
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
import _multiprocessing
from multiprocessing import connection
#"
#/>
     
# -------------------------------------------------------------------------------------------------
# Global constants                            
# ------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global MESSAGE_LENGTH
global CHALLENGE
global WELCOME
global FAILURE
global MAX_RESPONSE_MESSAGE_LENGTH
global LOCALHOST
global BUFSIZE
global CONNECTION_TIMEOUT             #[Rel 7.21]


#"
#/>

# -------------------------------------------------------------------------------------------------
# Settings
# -------------------------------------------------------------------------------------------------
#<set4xi setting = "
BUFSIZE = 8192                        #original
CHALLENGE = b'#CHALLENGE#'
LOCALHOST = 'localhost'
FAILURE = b'#FAILURE#'
MAX_RESPONSE_MESSAGE_LENGTH = 256     #original
MESSAGE_LENGTH = 20                   #original
WELCOME = b'#WELCOME#'
CONNECTION_TIMEOUT = 20.              #[Rel 7.21]
#"/>
                         

# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from print4xi import print4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from time4xi import time4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
#<function4xi function = "constant-connection4xi" usage = "
# defines constants for connections
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------
def constant_connection4xi(self, param_constant_connection4xi):
    '''
    constant_connection4xi defines constants for connections

    '''
    
    global MESSAGE_LENGTH
    global CHALLENGE
    global WELCOME
    global FAILURE
    global MAX_RESPONSE_MESSAGE_LENGTH
    global LOCALHOST
    global BUFSIZE
    global CONNECTION_TIMEOUT             #[Rel 7.21]
      
    
    class2print = 'constant_connection4xi'
    method2print = 'constant_connection4xi'
    
    message2print = "{started" + "; constant-connection4xi-started: " + str(constant_connection4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)            
        
    message2print = "{passed" + "; param-constant-connection4xi-passed-to-constant-connection4xi: " + str(param_constant_connection4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
              
    if param_constant_connection4xi == 1:
    
        message2print = "{returning" + "; message-length-returning-by-constant-connection4xi: " + str(MESSAGE_LENGTH) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   

        return MESSAGE_LENGTH

    if param_constant_connection4xi == 2:
    
        message2print = "{returning" + "; challenge-returning-by-constant-connection4xi: " + str(CHALLENGE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
 
     
        return CHALLENGE        

    if param_constant_connection4xi == 3:
    
        message2print = "{returning" + "; welcome-returning-by-constant-connection4xi: " + str(WELCOME) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
 
     
        return WELCOME
        
    if param_constant_connection4xi == 4:
    
        message2print = "{returning" + "; failure-returning-by-constant-connection4xi: " + str(FAILURE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
  
     
        return FAILURE
        
    if param_constant_connection4xi == 5:
    
        message2print = "{returning" + "; max-response-MESSAGE-LENGTH-returning-by-constant-connection4xi: " + str(MAX_RESPONSE_MESSAGE_LENGTH) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
 
     
        return MAX_RESPONSE_MESSAGE_LENGTH 
           
    if param_constant_connection4xi == 6:
    
        message2print = "{returning" + "; localhost-returning-by-constant-connection4xi: " + str(LOCALHOST) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
  
     
        return LOCALHOST    
    
    if param_constant_connection4xi == 7:
    
        message2print = "{returning" + "; bufsize-returning-by-constant-connection4xi: " + str(BUFSIZE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
 
     
        return BUFSIZE 
        
    if param_constant_connection4xi == 8:
    
        message2print = "{returning" + "; connection_timeout-returning-by-constant-connection4xi: " + str(CONNECTION_TIMEOUT) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
 
     
        return CONNECTION_TIMEOUT              

    message2print = "{returning" + "; false-returning-by-constant-connection4xi: " + str(False) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
    
    return False        
#</function4xi> 

 
 
# =================================================================================================
# I Object MESSAGE_LENGTH 
# =================================================================================================
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-message-length4xi" usage = "
# initializes MESSAGE_LENGTH
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_message_length4xi(param_init_message_length4xi=20):          
    '''
    init_message_length4xi initializes MESSAGE_LENGTH
    '''
    global MESSAGE_LENGTH
    
    class2print = 'init_message_length4xi'
    method2print = 'init_message_length4xi'
    
    message2print = "{started" + "; init-message-length4xi-started: " + str(init_message_length4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)      
    # <function init_connectiontimeout4xi at 0x0000000002BDC6A8>
    
    message2print = "{passed" + "; param-init-message-length4xi-passed-to-init-message-length4xi: " + str(param_init_message_length4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    # 20.0    
      
    if param_init_message_length4xi:
        MESSAGE_LENGTH = param_init_message_length4xi
    else:
        MESSAGE_LENGTH = 20         
    
    message2print = "{initialized" + "; message-length-initialized-by-init-message-length4xi to: " + str(MESSAGE_LENGTH)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    # 20.0
    
    message2print = "{returning" + "; init-message-length4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
    # 03:28:56 10/10/12 Pacific Daylight Time                 

#</function4xi> 

            
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-message-length4xi" usage = "
# sets MESSAGE_LENGTH
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_message_length4xi(param_set_message_length4xi=20):          
    '''
    set_message_length4xi sets MESSAGE_LENGTH
    '''
    global MESSAGE_LENGTH
    
    class2print = 'set_message_length4xi'
    method2print = 'set_message_length4xi'
    
    message2print = "{started" + "; set-message-length4xi-started: " + str(set_message_length4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-set-message-length4xi-passed-to-set-message-length4xi: " + str(param_set_message_length4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_set_message_length4xi:
        MESSAGE_LENGTH = param_set_message_length4xi
    else:
        MESSAGE_LENGTH = 20                

    message2print = "{set" + "; message-length-set-by-set-message-length4xi to: " + str(MESSAGE_LENGTH)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    message2print = "{returning" + "; set-message-length4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                
#</function4xi> 

            
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-message-length4xi" usage = "
# gets MESSAGE_LENGTH
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_message_length4xi():          
    '''
    get_message_length4xi gets MESSAGE_LENGTH
    '''
    global MESSAGE_LENGTH
    
    class2print = 'get_message_length4xi'
    method2print = 'get_message_length4xi'
    
    message2print = "{started" + "; get-message-length4xi-started: " + str(get_message_length4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    if MESSAGE_LENGTH:
        
        message2print = "{returning" + "; message-length-returning-by-get-message-length4xi: " + str(MESSAGE_LENGTH) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
        
        return MESSAGE_LENGTH
    else:
        init_message_length4xi(20)
        
        message2print = "{returning" + "; message-length-returning-by-get-message-length4xi: " + str(MESSAGE_LENGTH) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
        
        return MESSAGE_LENGTH 
#</function4xi> 

 
# =================================================================================================
# II Object CHALLENGE
# =================================================================================================    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-challenge4xi" usage = "
# initializes CHALLENGE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_challenge4xi(param_init_challenge4xi=b'#CHALLENGE#'):          
    '''
    init_challenge4xi initializes CHALLENGE
    '''
    global CHALLENGE
    
    class2print = 'init_challenge4xi'
    method2print = 'init_challenge4xi'
    
    message2print = "{started" + "; init-challenge4xi-started: " + str(init_challenge4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{passed" + "; param-init-challenge4xi-passed-to-init-challenge4xi: " + str(param_init_challenge4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_init_challenge4xi:
        CHALLENGE = param_init_challenge4xi
    else:
        CHALLENGE = b'#CHALLENGE#'         

    message2print = "{initialized" + "; challenge-initialized-by-init-challenge4xi to: " + str(CHALLENGE)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{returning" + "; init-challenge4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                    
#</function4xi> 

    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-challenge4xi" usage = "
# sets CHALLENGE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_challenge4xi(param_set_challenge4xi=b'#CHALLENGE#'):          
    '''
    set_challenge4xi sets CHALLENGE
    '''
    global CHALLENGE
    
    class2print = 'set_challenge4xi'
    method2print = 'set_challenge4xi'
    
    message2print = "{started" + "; set-challenge4xi-started: " + str(set_challenge4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{passed" + "; param-set-challenge4xi-passed-to-set-challenge4xi: " + str(param_set_challenge4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
            
          
    if param_set_challenge4xi:
        CHALLENGE = param_set_challenge4xi
    else:
        CHALLENGE = b'#CHALLENGE#'                
    
    message2print = "{set" + "; challenge-set-by-set-challenge4xi to: " + str(CHALLENGE)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    message2print = "{returning" + "; set-challenge4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        
#</function4xi> 

            
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-challenge4xi" usage = "
# gets CHALLENGE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_challenge4xi():          
    '''
    get_challenge4xi gets CHALLENGE
    '''
    global CHALLENGE
    
    class2print = 'get_challenge4xi'
    method2print = 'get_challenge4xi'    
    
    message2print = "{started" + "; get-challenge4xi-started: " + str(get_challenge4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
        
    if CHALLENGE:
    
        message2print = "{returning" + "; challenge-returning-by-get-challenge4xi: " + str(CHALLENGE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
        
        return CHALLENGE
    else:
        init_challenge4xi(b'#CHALLENGE#')
    
        message2print = "{returning" + "; challenge-returning-by-get-challenge4xi: " + str(CHALLENGE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
           
        return CHALLENGE  
#</function4xi> 

               
# =================================================================================================
# III Object WELCOME
# =================================================================================================    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-welcome4xi" usage = "
# initializes WELCOME
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_welcome4xi(param_init_welcome4xi=b'#WELCOME#'):          
    '''
    init_welcome4xi initializes WELCOME
    '''
    global WELCOME
    
    class2print = 'init_welcome4xi'
    method2print = 'init_welcome4xi'    
    
    message2print = "{started" + "; init-welcome4xi-started: " + str(init_welcome4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-init-welcome4xi-passed-to-init-welcome4xi: " + str(param_init_welcome4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
            

          
    if param_init_welcome4xi:
        WELCOME = param_init_welcome4xi
    else:
        WELCOME = b'#WELCOME#'         
    
    message2print = "{initialized" + "; welcome-initialized-by-init-welcome4xi to: " + str(WELCOME)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
                
    message2print = "{returning" + "; init-welcome4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        
#</function4xi> 

        
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-welcome4xi" usage = "
# sets WELCOME
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_welcome4xi(param_set_welcome4xi=b'#WELCOME#'):          
    '''
    set_welcome4xi sets WELCOME
    '''
    global WELCOME
    
    class2print = 'set_welcome4xi'
    method2print = 'set_welcome4xi'    
    
    message2print = "{started" + "; set-welcome4xi-started: " + str(set_welcome4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)        
    
    message2print = "{passed" + "; param-set-welcome4xi-passed-to-set-welcome4xi: " + str(param_set_welcome4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_set_welcome4xi:
        WELCOME = param_set_welcome4xi
    else:
        WELCOME = b'#WELCOME#'                
    
    message2print = "{set" + "; welcome-set-by-set-welcome4xi to: " + str(WELCOME)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    
    message2print = "{returning" + "; set-welcome4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                

#</function4xi> 

                
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-welcome4xi" usage = "
# gets WELCOME
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_welcome4xi():          
    '''
    get_welcome4xi gets WELCOME
    '''
    global WELCOME
    
    class2print = 'get_welcome4xi'
    method2print = 'get_welcome4xi'
    
    message2print = "{started" + "; get-welcome4xi-started: " + str(get_welcome4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
        
    if WELCOME:
        
        message2print = "{returning" + "; welcome-returning-by-get-welcome4xi: " + str(WELCOME) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
 
        return WELCOME
    else:
        init_welcome4xi(b'#WELCOME#')
        
        message2print = "{returning" + "; welcome-returning-by-get-welcome4xi: " + str(WELCOME) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
         
        
        return WELCOME          
#</function4xi> 

        
# =================================================================================================
# IV Object FAILURE
# =================================================================================================    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-failure4xi" usage = "
# initializes FAILURE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_failure4xi(param_init_failure4xi=b'#FAILURE#'):          
    '''
    init_failure4xi initializes FAILURE
    '''
    global FAILURE
    
    class2print = 'init_failure4xi'
    method2print = 'init_failure4xi'
    
    message2print = "{started" + "; init-failure4xi-started: " + str(init_failure4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-init-failure4xi-passed-to-init-failure4xi: " + str(param_init_failure4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
              
    if param_init_failure4xi:
        FAILURE = param_init_failure4xi
    else:
        FAILURE = b'#FAILURE#'  
    
    message2print = "{initialized" + "; failure-initialized-by-init-failure4xi to: " + str(FAILURE)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{returning" + "; init-failure4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                               

#</function4xi> 

            
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-failure4xi" usage = "
# sets FAILURE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_failure4xi(param_set_failure4xi=b'#FAILURE#'):          
    '''
    set_failure4xi sets FAILURE
    '''
    global FAILURE
    
    class2print = 'set_failure4xi'
    method2print = 'set_failure4xi'    
    
    message2print = "{started" + "; set-failure4xi-started: " + str(set_failure4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{passed" + "; param-set-failure4xi-passed-to-set-failure4xi: " + str(param_set_failure4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_set_failure4xi:
        FAILURE = param_set_failure4xi
    else:
        FAILURE = b'#FAILURE#'                
    
    message2print = "{set" + "; failure-set-by-set-failure4xi to: " + str(FAILURE)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    message2print = "{returning" + "; set-failure4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        
#</function4xi> 

            
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-failure4xi" usage = "
# gets FAILURE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_failure4xi():          
    '''
    get_failure4xi gets FAILURE
    '''
    global FAILURE
    
    class2print = 'get_failure4xi'
    method2print = 'get_failure4xi'
    
    message2print = "{started" + "; get-failure4xi-started: " + str(get_failure4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
        
    
    if FAILURE:
    
        message2print = "{returning" + "; failure-returning-by-get-failure4xi: " + str(FAILURE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
          
        return FAILURE
    else:
        init_failure4xi(b'#FAILURE#')
        
    
        message2print = "{returning" + "; failure-returning-by-get-failure4xi: " + str(FAILURE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
  
        return FAILURE                 
#</function4xi> 

        
# =================================================================================================
# V Object MAX_RESPONSE_MESSAGE_LENGTH
# =================================================================================================    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-max-response-message-length4xi" usage = "
# initializes MAX_RESPONSE_MESSAGE_LENGTH
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_max_response_message_length4xi(param_init_max_response_message_length4xi=8192):         
    '''
    init_max_response_message_length4xi initializes MAX_RESPONSE_MESSAGE_LENGTH
    '''
    global MAX_RESPONSE_MESSAGE_LENGTH
    
    class2print = 'init_max_response_message_length4xi'
    method2print = 'init_max_response_message_length4xi'    
    
    message2print = "{started" + "; init-max-response-message-length4xi-started: " + str(init_max_response_message_length4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-init-max-response-message-length4xi-passed-to-init-max-response-message-length4xi: " + str(param_init_max_response_message_length4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_init_max_response_message_length4xi:
        MAX_RESPONSE_MESSAGE_LENGTH = param_init_max_response_message_length4xi
    else:
        MAX_RESPONSE_MESSAGE_LENGTH = 8192         

    message2print = "{initialized" + "; max-response-message-length-initialized-by-init-max-response-message-length4xi to: " + str(MAX_RESPONSE_MESSAGE_LENGTH)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
            
    message2print = "{returning" + "; init-max-response-message-length4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        
                   
#</function4xi> 

         
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-max-response-message-length4xi" usage = "
# sets MAX_RESPONSE_MESSAGE_LENGTH
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_max_response_message_length4xi(param_set_max_response_message_length4xi=8192):          
    '''
    set_max_response_message_length4xi sets MAX_RESPONSE_MESSAGE_LENGTH
    '''
    global MAX_RESPONSE_MESSAGE_LENGTH
    
    class2print = 'set_max_response_message_length4xi'
    method2print = 'set_max_response_message_length4xi'    
    
    message2print = "{started" + "; set-max-response-message-length4xi-started: " + str(set_max_response_message_length4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-set-max-response-message-length4xi-passed-to-set-max-response-message-length4xi: " + str(param_set_max_response_message_length4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_set_max_response_message_length4xi:
        MAX_RESPONSE_MESSAGE_LENGTH = param_set_max_response_message_length4xi
    else:
        MAX_RESPONSE_MESSAGE_LENGTH = 8192                

    message2print = "{set" + "; max-response-message-length-set-by-set-max-response-message-length4xi to: " + str(MAX_RESPONSE_MESSAGE_LENGTH)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    message2print = "{returning" + "; set-max-response-message-length4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        
                           
#</function4xi> 

         
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-max-response-message-length4xi" usage = "
# gets MAX_RESPONSE_MESSAGE_LENGTH
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_max_response_message_length4xi():          
    '''
    getmax_response_message_length4xi gets MAX_RESPONSE_MESSAGE_LENGTH
    '''
    global MAX_RESPONSE_MESSAGE_LENGTH
    
    class2print = 'get_max_response_message_length4xi'
    method2print = 'get_max_response_message_length4xi'
    
    message2print = "{started" + "; get-max-response-message-length4xi-started: " + str(get_max_response_message_length4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    if MAX_RESPONSE_MESSAGE_LENGTH:
    
        message2print = "{returning" + "; max-response-message-length-returning-by-get-max-response-message-length4xi: " + str(MAX_RESPONSE_MESSAGE_LENGTH) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
 
        return MAX_RESPONSE_MESSAGE_LENGTH
    else:
        initmax_response_message_length4xi(8192)
    
        message2print = "{returning" + "; max-response-message-length-returning-by-get-max-response-message-length4xi: " + str(MAX_RESPONSE_MESSAGE_LENGTH) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
  
        return MAX_RESPONSE_MESSAGE_LENGTH                       
#</function4xi> 

        
# =================================================================================================
# VI Object LOCALHOST
# =================================================================================================    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-localhost4xi" usage = "
# initializes LOCALHOST
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_localhost4xi(param_init_localhost4xi='localhost'):          
    '''
    init_localhost4xi initializes LOCALHOST
    '''
    global LOCALHOST
    
    class2print = 'init_localhost4xi'
    method2print = 'init_localhost4xi'    
    
    message2print = "{started" + "; init-localhost4xi-started: " + str(init_localhost4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-init-localhost4xi-passed-to-init-localhost4xi: " + str(param_init_localhost4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_init_localhost4xi:
        LOCALHOST = param_init_localhost4xi
    else:
        LOCALHOST = 'localhost'         
    
    message2print = "{initialized" + "; localhost-initialized-by-init-localhost4xi to: " + str(LOCALHOST)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
        
    message2print = "{returning" + "; init-localhost4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                   
#</function4xi> 

         
        
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-localhost4xi" usage = "
# sets LOCALHOST
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_localhost4xi(param_set_localhost4xi='localhost'):          
    '''
    set_localhost4xi sets LOCALHOST
    '''
    global LOCALHOST
    
    class2print = 'set_localhost4xi'
    method2print = 'set_localhost4xi'
    
    message2print = "{started" + "; set-localhost4xi-started: " + str(set_localhost4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-set-localhost4xi-passed-to-set-localhost4xi: " + str(param_set_localhost4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_set_localhost4xi:
        LOCALHOST = param_set_localhost4xi
    else:
        LOCALHOST = 'localhost'                

    message2print = "{set" + "; localhost-set-by-set-localhost4xi to: " + str(LOCALHOST)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    message2print = "{returning" + "; set-localhost4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                         
#</function4xi> 

         
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-localhost4xi" usage = "
# gets LOCALHOST
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_localhost4xi():          
    '''
    get_localhost4xi gets LOCALHOST
    '''
    global LOCALHOST
    
    class2print = 'get_localhost4xi'
    method2print = 'get_localhost4xi'
    
    message2print = "{started" + "; get-localhost4xi-started: " + str(get_localhost4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
        
    if LOCALHOST:
        
        message2print = "{returning" + "; localhost-returning-by-get-localhost4xi: " + str(LOCALHOST) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
        
        return LOCALHOST
    else:
        init_localhost4xi('localhost')
        
        message2print = "{returning" + "; localhost-returning-by-get-localhost4xi: " + str(LOCALHOST) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
   
        return LOCALHOST                       
#</function4xi> 

 
# =================================================================================================
# VII Object BUFSIZE
# =================================================================================================    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-buffersize4xi" usage = "
# initializes BUFSIZE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_buffersize4xi(param_init_buffersize4xi=8192):          
    '''
    init_buffersize4xi initializes BUFSIZE
    '''
    global BUFSIZE
    
    class2print = 'init_buffersize4xi'
    method2print = 'init_buffersize4xi'    
    
    message2print = "{started" + "; init-buffersize4xi-started: " + str(init_buffersize4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-init-buffersize4xi-passed-to-init-buffersize4xi: " + str(param_init_buffersize4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_init_buffersize4xi:
        BUFSIZE = param_init_buffersize4xi
    else:
        BUFSIZE = 8192 
                
    message2print = "{initialized" + "; bufsize-initialized-by-init-buffersize4xi to: " + str(BUFSIZE)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{returning" + "; init-buffersize4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                

#</function4xi> 

                    
        
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-buffersize4xi" usage = "
# sets BUFSIZE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_buffersize4xi(param_set_buffersize4xi=8192):          
    '''
    set_buffersize4xi sets BUFSIZE
    '''
    global BUFSIZE
    
    class2print = 'set_buffersize4xi'
    method2print = 'set_buffersize4xi'    
    
    message2print = "{started" + "; set-buffersize4xi-started: " + str(set_buffersize4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{passed" + "; param-set-buffersize4xi-passed-to-set-buffersize4xi: " + str(param_set_buffersize4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_set_buffersize4xi:
        BUFSIZE = param_set_buffersize4xi
    else:
        BUFSIZE = 8192                

    message2print = "{set" + "; bufsize-set-by-set-buffersize4xi to: " + str(BUFSIZE)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    message2print = "{returning" + "; set-buffersize4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                    
#</function4xi> 

         
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-buffersize4xi" usage = "
# gets BUFSIZE
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_buffersize4xi():          
    '''
    get_buffersize4xi gets BUFSIZE
    '''
    global BUFSIZE
    
    class2print = 'get_buffersize4xi'
    method2print = 'get_buffersize4xi'
    
    message2print = "{started" + "; get-buffersize4xi-started: " + str(get_buffersize4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
        
    if BUFSIZE:
        
        message2print = "{returning" + "; bufsize-returning-by-get-buffersize4xi: " + str(BUFSIZE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
        
        return BUFSIZE
    else:
        init_buffersize4xi(8192)
        
        message2print = "{returning" + "; BUFSIZE-returning-by-get-buffersize4xi: " + str(BUFSIZE) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
   
        return BUFSIZE                            
#</function4xi> 

 
# =================================================================================================
# VIII Object CONNECTION_TIMEOUT #[Rel 7.21]
# =================================================================================================    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-connectiontimeout4xi" usage = "
# initializes CONNECTION_TIMEOUT
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_connectiontimeout4xi(param_init_connectiontimeout4xi=20.):          
    '''
    init_connectiontimeout4xi initializes CONNECTION_TIMEOUT
    '''
    global CONNECTION_TIMEOUT
    
    class2print = 'init_connectiontimeout4xi'
    method2print = 'init_connectiontimeout4xi'    
    
    message2print = "{(Step 1/4) started" + "; init-connectiontimeout4xi-started: " + str(init_connectiontimeout4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{(Step 2/4) passed" + "; param-init-connectiontimeout4xi-passed-to-init-connectiontimeout4xi: " + str(param_init_connectiontimeout4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_init_connectiontimeout4xi:
        CONNECTION_TIMEOUT = param_init_connectiontimeout4xi
    else:
        CONNECTION_TIMEOUT = 20. 
                
    message2print = "{(Step 3/4) initialized" + "; bufsize-initialized-by-init-connectiontimeout4xi to: " + str(CONNECTION_TIMEOUT)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{(Step 4/4) returning" + "; init-connectiontimeout4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                

#</function4xi> 

                    
        
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-connectiontimeout4xi" usage = "
# sets CONNECTION_TIMEOUT
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_connectiontimeout4xi(param_set_connectiontimeout4xi=20.):          
    '''
    set_connectiontimeout4xi sets CONNECTION_TIMEOUT
    '''
    global CONNECTION_TIMEOUT
    
    class2print = 'set_connectiontimeout4xi'
    method2print = 'set_connectiontimeout4xi'    
    
    message2print = "{(Step 1/4) started" + "; set-connectiontimeout4xi-started: " + str(set_connectiontimeout4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    message2print = "{(Step 2/4) passed" + "; param-set-connectiontimeout4xi-passed-to-set-connectiontimeout4xi: " + str(param_set_connectiontimeout4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
          
    if param_set_connectiontimeout4xi:
        CONNECTION_TIMEOUT = param_set_connectiontimeout4xi
    else:
        CONNECTION_TIMEOUT = 20.                

    message2print = "{(Step 3/4) set" + "; bufsize-set-by-set-connectiontimeout4xi to: " + str(CONNECTION_TIMEOUT)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
        
    message2print = "{(Step 4/4) returning" + "; set-connectiontimeout4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                    
#</function4xi> 

         
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-connectiontimeout4xi" usage = "
# gets CONNECTION_TIMEOUT
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_connectiontimeout4xi():          
    '''
    get_connectiontimeout4xi gets CONNECTION_TIMEOUT
    '''
    global CONNECTION_TIMEOUT
    
    class2print = 'get_connectiontimeout4xi'
    method2print = 'get_connectiontimeout4xi'
    
    message2print = "{(Step 1/3) started" + "; get-connectiontimeout4xi-started: " + str(get_connectiontimeout4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    # <function get_connectiontimeout4xi at 0x0000000002C0BD90>
        
    if CONNECTION_TIMEOUT:
        
        message2print = "{(Step 2/3) returning" + "; CONNECTION_TIMEOUT-returning-by-get-connectiontimeout4xi: " + str(CONNECTION_TIMEOUT) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        # (Step 2/3) returning; CONNECTION_TIMEOUT-returning-by-get-connectiontimeout4xi: 20.0
        
        return CONNECTION_TIMEOUT
    else:
        init_connectiontimeout4xi(20.)
        
        message2print = "{(Step 3/3) returning" + "; CONNECTION_TIMEOUT-returning-by-get-connectiontimeout4xi: " + str(CONNECTION_TIMEOUT) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
   
        return CONNECTION_TIMEOUT                            
#</function4xi> 


                       
# =================================================================================================
#<class4xi class = "ConstantConnection4Xi" base = "object" child = "None" synopsis = "offers services for connection constants"
#>
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# =================================================================================================
class ConstantConnection4Xi(object): #<-- inherits from object class
    '''
    ConstantConnection4Xi offers services for connection constants
    ''' 
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi expose = "
    _exposed_ = ( 'init_message_length', 'set_message_length', 'get_message_length', 
                  'init_challenge', 'set_challenge', 'get_challenge',
                  'init_welcome', 'set_welcome', 'get_welcome',
                  'init_failure', 'set_failure', 'get_failure',
                  'init_max_response_message_length', 'set_max_response_message_length', 'get_max_response_message_length',
                  'init_localhost', 'set_localhost', 'get_localhost',
                  'init_buffersize', 'set_buffersize', 'get_buffersize',
                  'init_connectiontimeout', 'set_connectiontimeout', 'get_connectiontimeout',#[Rel 7.21]
                  'sense', 'reason', 'ace')          
    #"
    #/>
                                                
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-of-ConstantConnection4Xi" usage = "initializes connections constants">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def __init__(self,
                 length=20,
                 challenge=b'#CHALLENGE#',
                 welcome=b'#WELCOME#',
                 failure=b'#FAILURE#',
                 msg_length=8192,
                 host='localhost',
                 buffersize=8192,
                 connectiontimeout=20.):#[Rel 7.21]
        '''
        __init__: initializes connections constants
        '''
        
        class2print = 'ConstantConnection4Xi'
        method2print = '__init__' 
        
        message2print = "{(Step 0/A) started" + "; init-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 03:46:40 10/10/12 Pacific Daylight Time
        
        message2print = "{(Step 0/B) borning" + "; constantconnection2xi-of-ConstantConnection4Xi-borning: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        # 03:46:40 10/10/12 Pacific Daylight Time
        
        message2print = "{(Step 0/C) inheriting" + "; object-inheriting-by-constantconnection2xi-of-ConstantConnection4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        # <class 'object'>
        
        #(1/8)                                       
        message2print = "{(Step 0/D1) passed" + "; length-passed-to-init-of-ConstantConnection4Xi: " + str(length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        #(2/8)                                  
        message2print = "{(Step 0/D2) passed" + "; challenge-passed-to-init-of-ConstantConnection4Xi: " + str(challenge) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        #(3/8)                                  
        message2print = "{(Step 0/D3) passed" + "; welcome-passed-to-init-of-ConstantConnection4Xi: " + str(welcome) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        #(4/8)                                  
        message2print = "{(Step 0/D4) passed" + "; failure-passed-to-init-of-ConstantConnection4Xi: " + str(failure) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        #(5/8)                                  
        message2print = "{(Step 0/D5) passed" + "; msg-length-passed-to-init-of-ConstantConnection4Xi: " + str(msg_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        #(6/8)                                  
        message2print = "{(Step 0/D6) passed" + "; host-passed-to-init-of-ConstantConnection4Xi: " + str(host) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        #(7/8)                                  
        message2print = "{(Step 0/D7) passed" + "; buffersize-passed-to-init-of-ConstantConnection4Xi: " + str(buffersize) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        #(8/8)
        message2print = "{(Step 0/D8) passed" + "; connectiontimeout-passed-to-init-of-ConstantConnection4Xi: " + str(connectiontimeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)              

        #(1/8)
        message2print = "{(Step 0E1/33) passing" + "; length-passing-to-init-message-length4xi-by-init-of-ConstantConnection4Xi: " + str(length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
 
        # length-passed-to-init-of-ConstantConnection4Xi: 30; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # challenge-passed-to-init-of-ConstantConnection4Xi: b'#CHALLENGE#3'; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # welcome-passed-to-init-of-ConstantConnection4Xi: b'#WELCOME#3'; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # failure-passed-to-init-of-ConstantConnection4Xi: b'#FAILURE#3'; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # msg-length-passed-to-init-of-ConstantConnection4Xi: 384; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # host-passed-to-init-of-ConstantConnection4Xi: localhost3; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # buffersize-passed-to-init-of-ConstantConnection4Xi: 1024; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # connectiontimeout-passed-to-init-of-ConstantConnection4Xi: 21.0; time: 03:46:40 10/10/12 Pacific Daylight Time}        
        
                                                        
        init_message_length4xi(length)
        
        #(2/8)
        message2print = "{(Step 0E2/8) passing" + "; challenge-passing-to-init-challenge4xi-by-init-of-ConstantConnection4Xi: " + str(challenge) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
            
        init_challenge4xi(challenge)
        
        #(3/8)
        message2print = "{(Step 0E3/8) passing" + "; welcome-passing-to-init-welcome4xi-by-init-of-ConstantConnection4Xi: " + str(welcome) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
            
        init_welcome4xi(welcome)
        
        #(4/8)
        message2print = "{(Step 0E4/8) passing" + "; failure-passing-to-init-failure4xi-by-init-of-ConstantConnection4Xi: " + str(failure) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
            
        init_failure4xi(failure)

        #(5/8)
        message2print = "{(Step 0E5/8) passing" + "; msg-length-passing-to-init-max-response-message-length4xi-by-init-of-ConstantConnection4Xi: " + str(msg_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
            
        init_max_response_message_length4xi(msg_length)

        #(6/8)
        message2print = "{(Step 0E6/8) passing" + "; host-passing-to-init-localhost4xi-by-init-of-ConstantConnection4Xi: " + str(host) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
            
        init_localhost4xi(host)

        #(7/8)
        message2print = "{(Step 0E7/8) passing" + "; buffersize-passing-to-init-buffersize4xi-by-init-of-ConstantConnection4Xi: " + str(buffersize) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
            
        init_buffersize4xi(buffersize)

        #(8/8)
        message2print = "{(Step 0E8/8) passing" + "; connectiontimeout-passing-to-init-connectiontimeout4xi-by-init-of-ConstantConnection4Xi: " + str(connectiontimeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
        # length-passing-to-init-message-length4xi-by-init-of-ConstantConnection4Xi: 30; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # challenge-passing-to-init-challenge4xi-by-init-of-ConstantConnection4Xi: b'#CHALLENGE#3'; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # welcome-passing-to-init-welcome4xi-by-init-of-ConstantConnection4Xi: b'#WELCOME#3'; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # failure-passing-to-init-failure4xi-by-init-of-ConstantConnection4Xi: b'#FAILURE#3'; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # msg-length-passing-to-init-max-response-message-length4xi-by-init-of-ConstantConnection4Xi: 384; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # host-passing-to-init-localhost4xi-by-init-of-ConstantConnection4Xi: localhost3; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # buffersize-passing-to-init-buffersize4xi-by-init-of-ConstantConnection4Xi: 1024; time: 03:46:40 10/10/12 Pacific Daylight Time}
        # connectiontimeout-passing-to-init-connectiontimeout4xi-by-init-of-ConstantConnection4Xi: 21.0; time: 03:46:40 10/10/12 Pacific Daylight Time}
          
        init_connectiontimeout4xi(connectiontimeout)
        
                
        message2print = "{(Step 0F1/33) activated" + "; constantconnection2xi-of-ConstantConnection4Xi-activated: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        #  03:46:40 10/10/12 Pacific Daylight Time
        message2print = "{(Step 0F2/33) inherited" + "; object-inherited-by-constantconnection2xi-of-ConstantConnection4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        # <class 'object'>      
        message2print = "{(Step 0F3/33) returning" + "; init-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
        # 03:46:40 10/10/12 Pacific Daylight Time
                         
                
                        
                                          
    #</methodize4xi>
    

        
    # =================================================================================================
    # I Object MESSAGE_LENGTH4XI
    # =================================================================================================
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-message-length-of-ConstantConnection4Xi" usage = "initializes MESSAGE_LENGTH4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_message_length(self,param_init_message_length=20):          
        '''
        init_message_length initializes MESSAGE_LENGTH4XI
        '''
        class2print = 'ConstantConnection4Xi'
        method2print = 'init_message_length' 
        
        message2print = "{(Step 1/4) started" + "; init-message-length-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-message-length-passed-to-init-message-length-of-ConstantConnection4Xi: " + str(param_init_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param_init_message_length-passing-to-init-message-length4xi-by-init-message-length-of-ConstantConnection4Xi: " + str(param_init_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

                         
        init_message_length4xi(param_init_message_length)

        message2print = "{(Step 4/4) returning" + "; init-message-length-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                        
    #</methodize4xi>
              
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-message-length-of-ConstantConnection4Xi" usage = "sets MESSAGE_LENGTH4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_message_length(self,param_set_message_length=20):          
        '''
        set_message_length sets MESSAGE_LENGTH4XI
        '''
        class2print = 'ConstantConnection4Xi'
        method2print = 'set_message_length' 
        
        message2print = "{(Step 1/4) started" + "; set-message-length-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
          
    
        message2print = "{(Step 2/4) passed" + "; param-set-message-length-passed-to-set-message-length-of-ConstantConnection4Xi: " + str(param_set_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-message-length-passing-to-set-message-length4xi-by-set-message-length-of-ConstantConnection4Xi: " + str(param_set_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

           
        set_message_length4xi(param_set_message_length)              


        message2print = "{(Step 4/4) returning" + "; set-message-length-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
                       
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-message-length-of-ConstantConnection4Xi" usage = "gets MESSAGE_LENGTH4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_message_length(self):          
        '''
        get_message_length gets MESSAGE_LENGTH4XI
        '''
        class2print = 'ConstantConnection4Xi'
        method2print = 'set_message_length' 
        
        message2print = "{(Step 1/2) started" + "; get-message-length-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)             
          

        message2print = "{(Step 2/2) returning" + "; get-message_length4xi-function-returning-by-get-message-length-of-ConstantConnection4Xi: " + str(get_message_length4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
    
                
        return get_message_length4xi()  
    #</methodize4xi>
        
    # =================================================================================================
    # II Object CHALLENGE4XI
    # =================================================================================================    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-challenge-of-ConstantConnection4Xi" usage = "initializes CHALLENGE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_challenge(self,param_init_challenge=b'#CHALLENGE#'):          
        '''
        init_challenge initializes CHALLENGE4XI
        '''
        class2print = 'ConstantConnection4Xi'
        method2print = 'init_challenge' 
        
        message2print = "{(Step 1/4) started" + "; init-challenge-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-challenge-passed-to-init-challenge-of-ConstantConnection4Xi: " + str(param_init_challenge) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-init-challenge-passing-to-init-challenge4xi-by-init-challenge-of-ConstantConnection4Xi: " + str(param_init_challenge) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        init_challenge4xi(param_init_challenge)        
                

        message2print = "{(Step 4/4) returning" + "; init-challenge-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
           
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-challenge-of-ConstantConnection4Xi" usage = "sets CHALLENGE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_challenge(self,param_set_challenge=b'#CHALLENGE#'):          
        '''
        set_challenge sets CHALLENGE4XI
        '''
        class2print = 'ConstantConnection4Xi'
        method2print = 'set_challenge' 
        
        message2print = "{(Step 1/4) started" + "; set-challenge-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
    
    
        message2print = "{(Step 2/4) passed" + "; param-set-challenge-passed-to-set-challenge-of-ConstantConnection4Xi: " + str(param_set_challenge) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-challenge-passing-to-set-challenge4xi-by-set-challenge-of-ConstantConnection4Xi: " + str(param_set_challenge) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        set_challenge4xi(param_set_challenge)     
        

        message2print = "{(Step 4/4) returning" + "; set-challenge-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
           
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-challenge-of-ConstantConnection4Xi" usage = "gets CHALLENGE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_challenge(self):          
        '''
        get_challenge gets CHALLENGE4XI
        '''
        class2print = 'ConstantConnection4Xi'
        method2print = 'set_challenge' 
        
        message2print = "{(Step 1/2) started" + "; get-challenge-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
          

        message2print = "{(Step 2/2) returning" + "; get-challenge4xi-function-returning-by-get-challenge-of-ConstantConnection4Xi: " + str(get_challenge4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
   
               
        return get_challenge4xi()   
    #</methodize4xi>
                      
    # =================================================================================================
    # III Object WELCOME4XI
    # =================================================================================================    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-welcome-of-ConstantConnection4Xi" usage = "initializes WELCOME4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_welcome(self,param_init_welcome=b'#WELCOME#'):          
        '''
        init_welcome initializes WELCOME4XI
        '''
            
        class2print = 'ConstantConnection4Xi'
        method2print = 'init_welcome' 
        
        message2print = "{(Step 1/4) started" + "; init-welcome-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-welcome-passed-to-init-welcome-of-ConstantConnection4Xi: " + str(param_init_welcome) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-init-welcome-passing-to-init-welcome4xi-by-init-welcome-of-ConstantConnection4Xi: " + str(param_init_welcome) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        init_welcome4xi(param_init_welcome)
        

        message2print = "{(Step 4/4) returning" + "; init-welcome-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
                       
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-welcome-of-ConstantConnection4Xi" usage = "sets WELCOME4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_welcome(self,param_set_welcome=b'#WELCOME#'):          
        '''
        set_welcome sets WELCOME4XI
        '''
        class2print = 'ConstantConnection4Xi'
        method2print = 'set_welcome' 
        
        message2print = "{(Step 1/4) started" + "; set-welcome-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{(Step 2/4) passed" + "; param-set-welcome-passed-to-set-welcome-of-ConstantConnection4Xi: " + str(param_set_welcome) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-welcome-passing-to-set-welcome4xi-by-set-welcome-of-ConstantConnection4Xi: " + str(param_set_welcome) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        set_welcome4xi(param_set_welcome)
        

        message2print = "{(Step 4/4) returning" + "; set-welcome-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
                                                
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-welcome-of-ConstantConnection4Xi" usage = "gets WELCOME4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_welcome(self):          
        '''
        get_welcome gets WELCOME4XI
        '''
        class2print = 'ConstantConnection4Xi'        
        method2print = 'get_welcome' 
        
        message2print = "{(Step 1/2) started" + "; get-welcome-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)     
          

        message2print = "{(Step 2/2) returning" + "; get-welcome4xi-function-returning-by-get-welcome-of-ConstantConnection4Xi: " + str(get_welcome4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  

        
        return get_welcome4xi()        
    #</methodize4xi>
               
    # =================================================================================================
    # IV Object FAILURE4XI
    # =================================================================================================    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-failure-of-ConstantConnection4Xi" usage = "initializes FAILURE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_failure(self,param_init_failure=b'#FAILURE#'):          
        '''
        init_failure initializes FAILURE4XI
        '''
        class2print = 'ConstantConnection4Xi'        
        method2print = 'init_failure' 
        
        message2print = "{(Step 1/4) started" + "; init-failure-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-failure-passed-to-init-failure-of-ConstantConnection4Xi: " + str(param_init_failure) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-init-failure-passing-to-init-failure4xi-by-init-failure-of-ConstantConnection4Xi: " + str(param_init_failure) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        init_failure4xi(param_init_failure)           
                

        message2print = "{(Step 4/4) returning" + "; init-failure-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
                        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-failure-of-ConstantConnection4Xi" usage = "sets FAILURE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_failure(self,param_set_failure=b'#FAILURE#'):          
        '''
        set_failure sets FAILURE4XI
        '''
        class2print = 'ConstantConnection4Xi'        
        method2print = 'set_failure' 
        
        message2print = "{(Step 1/4) started" + "; set-failure-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
    
    
        message2print = "{(Step 2/4) passed" + "; param-set-failure-passed-to-set-failure-of-ConstantConnection4Xi: " + str(param_set_failure) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-failure-passing-to-set-failure4x-by-set-failure-of-ConstantConnection4Xi: " + str(param_set_failure) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        set_failure4xi(param_set_failure)        

        message2print = "{(Step 4/4) returning" + "; set-failure-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
                     
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-failure-of-ConstantConnection4Xi" usage = "gets FAILURE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_failure(self):          
        '''
        get_failure gets FAILURE4XI
        '''
        class2print = 'ConstantConnection4Xi'        
        method2print = 'get_failure' 
        
        message2print = "{(Step 1/2) started" + "; get-failure-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
          

        message2print = "{(Step 2/2) returning" + "; get-failure4xi-function-returning-by-get-failure-of-ConstantConnection4Xi: " + str(get_failure4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  

        return get_failure4xi()        
    #</methodize4xi>
               
    # =================================================================================================
    # V Object MAX_RESPONSE_MESSAGE_LENGTH4XI
    # =================================================================================================    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-max-response-message-length-of-ConstantConnection4Xi" usage = "initializes MAX_RESPONSE_MESSAGE_LENGTH4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_max_response_message_length(self, param_init_max_response_message_length=8192):          
        '''
        init_max_response_message_length initializes MAX_RESPONSE_MESSAGE_LENGTH4XI
        '''
        class2print = 'ConstantConnection4Xi'        
        method2print = 'init_max_response_message_length' 
        
        message2print = "{(Step 1/4) started" + "; init-max-response-message-length-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)             
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-max-response-message-length-passed-to-init-max-response-message-length-of-ConstantConnection4Xi: " + str(param_init_max_response_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-init-max-response-message-length-passing-to-init-max-response-message-length4xi-by-init-max-response-message-length-of-ConstantConnection4Xi: " + str(param_init_max_response_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        init_max_response_message_length4xi(param_init_max_response_message_length)  
                        

        message2print = "{(Step 4/4) returning" + "; init-max-response-message-length-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
                  
            
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-max-response-message-length-of-ConstantConnection4Xi" usage = "sets MAX_RESPONSE_MESSAGE_LENGTH4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_max_response_message_length(self,param_set_max_response_message_length=8192):          
        '''
        set_max_response_message_length sets MAX_RESPONSE_MESSAGE_LENGTH4XI
        '''
             
        class2print = 'ConstantConnection4Xi'        
        method2print = 'set_max_response_message_length' 
        
        message2print = "{(Step 1/4) started" + "; set-max-response-message-length-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
    
    
        message2print = "{(Step 2/4) passed" + "; param-set-max-response-message-length-passed-to-set-max-response-message-length-of-ConstantConnection4Xi: " + str(param_set_max_response_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-max-response-message-length-passing-to-set-max-response-message-length4xi-by-set-max-response-message-length-of-ConstantConnection4Xi: " + str(param_set_max_response_message_length) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        set_max_response_message_length4xi(param_set_max_response_message_length)        
                

        message2print = "{(Step 4/4) returning" + "; set-max-response-message-length-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
           
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-max-response-message-length-of-ConstantConnection4Xi" usage = "gets MAX_RESPONSE_MESSAGE_LENGTH4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_max_response_message_length(self):          
        '''
        getmax_response_message_length gets MAX_RESPONSE_MESSAGE_LENGTH4XI
        '''
        class2print = 'ConstantConnection4Xi'        
        method2print = 'get_max_response_message_length' 
        
        message2print = "{(Step 1/2) started" + "; get-max-response-message-length-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   


        message2print = "{(Step 2/2) returning" + "; get-max-response-message-length4xi-function-returning-by-get-max-response-message-length-of-ConstantConnection4Xi: " + str(get_max_response_message_length4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
   
        
        return get_max_response_message_length4xi()                     
    #</methodize4xi>
               
    # =================================================================================================
    # VI Object LOCALHOST4XI4XI
    # =================================================================================================    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-localhost-of-ConstantConnection4Xi" usage = "initializes LOCALHOST4XI4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_localhost(self, param_init_localhost='localhost'):          
        '''
        init_localhost initializes LOCALHOST4XI4XI
        '''
        class2print = 'ConstantConnection4Xi'        
        method2print = 'init_localhost' 
        
        message2print = "{(Step 1/4) started" + "; init-localhost-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)     
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-localhost-passed-to-init-localhost-of-ConstantConnection4Xi: " + str() + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-init-localhost-passing-to-init-localhost4xi-by-init-localhost-of-ConstantConnection4Xi: " + str(param_init_localhost) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        init_localhost4xi(param_init_localhost)
        

        message2print = "{(Step 4/4) returning" + "; init-localhost-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                                
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-localhost-of-ConstantConnection4Xi" usage = "sets LOCALHOST4XI4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_localhost(self, param_set_localhost='localhost'):          
        '''
        set_localhost sets LOCALHOST4XI4XI
        '''
        class2print = 'ConstantConnection4Xi'           
        method2print = 'set_localhost' 
        
        message2print = "{(Step 1/4) started" + "; set-localhost-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)     
    
    
        message2print = "{(Step 2/4) passed" + "; param-set-localhost-passed-to-set-localhost-of-ConstantConnection4Xi: " + str(param_set_localhost) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-localhost-passing-to-set-localhost4xi-by-set-localhost-of-ConstantConnection4X: " + str(param_set_localhost) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

     
        set_localhost4xi(param_set_localhost)             
                

        message2print = "{(Step 4/4) returning" + "; set-localhost-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
          

    #</methodize4xi>
              
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-localhost-of-ConstantConnection4Xi" usage = "gets LOCALHOST4XI4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_localhost(self):          
        '''
        get_localhost gets LOCALHOST4XI4XI
        '''
        class2print = 'ConstantConnection4Xi'   
        method2print = 'get_localhost' 
        
        message2print = "{(Step 1/2) started" + "; get-localhost-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
          

        message2print = "{(Step 2/2) returning" + "; get-localhost4xi-function-returning-by-get-localhost-of-ConstantConnection4Xi: " + str(get_localhost4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  

        
        return get_localhost4xi()
    #</methodize4xi>
                                           
    # =================================================================================================
    # VII Object BUFSIZE
    # =================================================================================================    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-buffersize-of-ConstantConnection4Xi" usage = "initializes BUFSIZE">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_buffersize(self, param_init_buffersize=8192):          
        '''
        init_buffersize initializes BUFSIZE
        '''
        
        class2print = 'ConstantConnection4Xi'   
        method2print = 'init_buffersize'
        
        message2print = "{(Step 1/4) started" + "; init-buffersize-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-buffersize-passed-to-init-buffersize-of-ConstantConnection4Xi: " + str(param_init_buffersize) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-init-buffersize-passing-to-init-buffersize4xi-by-init-buffersize-of-ConstantConnection4Xi: " + str(param_init_buffersize) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

              
        init_buffersize4xi(param_init_buffersize)
        

        message2print = "{(Step 4/4) returning" + "; init-buffersize-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
   
        

    #</methodize4xi>
                                               
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-buffersize-of-ConstantConnection4Xi" usage = "sets BUFSIZE">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_buffersize(self, param_set_buffersize=8192):          
        '''
        set_buffersize sets BUFSIZE
        '''
             
        class2print = 'ConstantConnection4Xi'   
        method2print = 'set_buffersize' 
        
        message2print = "{(Step 1/4) started" + "; set-buffersize-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
        message2print = "{(Step 2/4) passed" + "; param-set-buffersize-passed-to-set-buffersize-of-ConstantConnection4Xi: " + str(param_set_buffersize) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-buffersize-passing-to-set-buffersize4xi-by-set-buffersize-of-ConstantConnection4Xi: " + str(param_set_buffersize) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

        set_buffersize4xi(param_set_buffersize)          
                

        message2print = "{(Step 4/4) returning" + "; set-buffersize-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
      

    #</methodize4xi>
                          
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-buffersize-of-ConstantConnection4Xi" usage = "gets BUFSIZE">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_buffersize(self):          
        '''
        get_buffersize gets BUFSIZE
        '''
        class2print = 'ConstantConnection4Xi'   
        method2print = 'get_buffersize' 
        
        message2print = "{(Step 1/2) started" + "; get-buffersize-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          

        message2print = "{(Step 2/2) returning" + "; get-buffersize4xi-function-returning-by-get-buffersize-of-ConstantConnection4Xi: " + str(get_buffersize4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  

        return get_buffersize4xi()                     
    #</methodize4xi>
                                           
    # =================================================================================================
    # VIII Object CONNECTION_TIMEOUT #[Rel 7.21]
    # =================================================================================================    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-connectiontimeout-of-ConstantConnection4Xi" usage = "initializes CONNECTION_TIMEOUT">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_connectiontimeout(self, param_init_connectiontimeout=20.):          
        '''
        init_connectiontimeout initializes CONNECTION_TIMEOUT
        '''
        
        class2print = 'ConstantConnection4Xi'   
        method2print = 'init_connectiontimeout'
        
        message2print = "{(Step 1/4) started" + "; init-connectiontimeout-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
    
    
        message2print = "{(Step 2/4) passed" + "; param-init-connectiontimeout-passed-to-init-connectiontimeout-of-ConstantConnection4Xi: " + str(param_init_connectiontimeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-init-connectiontimeout-passing-to-init-connectiontimeout4xi-by-init-connectiontimeout-of-ConstantConnection4Xi: " + str(param_init_connectiontimeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

              
        init_connectiontimeout4xi(param_init_connectiontimeout)
        

        message2print = "{(Step 4/4) returning" + "; init-connectiontimeout-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
   
        

    #</methodize4xi>
                                               
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-connectiontimeout-of-ConstantConnection4Xi" usage = "sets CONNECTION_TIMEOUT">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_connectiontimeout(self, param_set_connectiontimeout=20.):          
        '''
        set_connectiontimeout sets CONNECTION_TIMEOUT
        '''
             
        class2print = 'ConstantConnection4Xi'   
        method2print = 'set_connectiontimeout' 
        
        message2print = "{(Step 1/4) started" + "; set-connectiontimeout-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
        message2print = "{(Step 2/4) passed" + "; param-set-connectiontimeout-passed-to-set-connectiontimeout-of-ConstantConnection4Xi: " + str(param_set_connectiontimeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
        message2print = "{(Step 3/4) passing" + "; param-set-connectiontimeout-passing-to-set-connectiontimeout4xi-by-set-connectiontimeout-of-ConstantConnection4Xi: " + str(param_set_connectiontimeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                

        set_connectiontimeout4xi(param_set_connectiontimeout)          
                

        message2print = "{(Step 4/4) returning" + "; set-connectiontimeout-of-ConstantConnection4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
      

    #</methodize4xi>
                          
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-connectiontimeout-of-ConstantConnection4Xi" usage = "gets CONNECTION_TIMEOUT">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_connectiontimeout(self):          
        '''
        get_connectiontimeout gets CONNECTION_TIMEOUT
        '''
        class2print = 'ConstantConnection4Xi'   
        method2print = 'get_connectiontimeout' 
        
        message2print = "{(Step 1/2) started" + "; get-connectiontimeout-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          

        message2print = "{(Step 2/2) returning" + "; get-connectiontimeout4xi-function-returning-by-get-connectiontimeout-of-ConstantConnection4Xi: " + str(get_connectiontimeout4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  

        return get_connectiontimeout4xi()                     
    #</methodize4xi>
                                       
                                               
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-ConstantConnection4Xi" usage = "senses class objects">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        senses ConstantConnection4Xi class objects
        '''
          
        
        class2print = 'ConstantConnection4Xi'
        method2print = 'sense'
        
        message2print = "{(Step 1/6) started" + "; sense-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{(Step 2/6) sensing" + "; constantconnection4xi-sensing-by-sense-of-ConstantConnection4Xi: " + str(ConstantConnection4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                        
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{(Step 3/6) got" + "; kb2xi-got-by-sense-of-ConstantConnection4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['inheritance-of-constantconnection2xi'] = object
        
        except:
            message2print = "{(Step 4/6) yielded" + "; kb2xi-yielded-by-sense-of-ConstantConnection4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 

      
        message2print = "{(Step 5/6) sensed" + "; constantconnection4xi-sensed-by-sense-of-ConstantConnection4Xi: " + str(ConstantConnection4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{(Step 6/6) returning" + "; kb2xi-returning-by-sense-of-ConstantConnection4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                 
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
            
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-ConstantConnection4Xi" usage = "reasons class objects">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        reasons ConstantConnection4Xi class objects
        '''
                 
        
        class2print = 'ConstantConnection4Xi'
        method2print = 'reason'

        message2print = "{(Step 1/5) started" + "; reason-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{(Step 2/5) reasoning" + "; constantconnection4xi-reasoning-by-reason-of-ConstantConnection4Xi: " + str(ConstantConnection4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                        
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{(Step 3/5) got" + "; kb4xi-got-by-reason-of-ConstantConnection4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                        
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        
        message2print = "{(Step 4/5) reasoned" + "; constantconnection4xi-reasoning-by-reason-of-ConstantConnection4Xi: " + str(ConstantConnection4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{(Step 5/5) returning" + "; kb4xi-returning-by-reason-of-ConstantConnection4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                              
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-ConstantConnection4Xi" usage = "aces class objects ">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        aces ConstantConnection4Xi class objects 
        '''
               
        
        
        class2print = 'ConstantConnection4Xi'
        method2print = 'ace'
        
        message2print = "{(Step 1/5) started" + "; ace-of-ConstantConnection4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)              
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{(Step 2/5) acing" + "; constantconnection4xi-acing-by-ace-of-ConstantConnection4Xi: " + str(ConstantConnection4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                      
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{(Step 3/5) got" + "; kb8xi-got-by-ace-of-ConstantConnection4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{(Step 4/5) aced" + "; constantconnection4xi-acing-by-ace-of-ConstantConnection4Xi: " + str(ConstantConnection4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{(Step 5/5) returning" + "; kb8xi-returning-by-ace-of-ConstantConnection4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                  
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_constant_connection4xi.txt
#   sense-test-constant-connection4xi.xml
#   reason-test-constant-connection4xi.xml
#   ace-test-constant-connection4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>

    
    

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of constant_connection4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>

